pub trait ConfigParentFallbackExt {
// Required method
fn get_with_parent_fallback(
&self,
parent: &str,
name: &str,
key: &str,
) -> Option<String>;
}Expand description
Extension trait to get values with parent table fallback.
This provides a consistent way to retrieve a value for a given logical name and fall back to the parent table when the specific name is not present.
Required Methods
Sourcefn get_with_parent_fallback(
&self,
parent: &str,
name: &str,
key: &str,
) -> Option<String>
fn get_with_parent_fallback( &self, parent: &str, name: &str, key: &str, ) -> Option<String>
Returns a string value for {parent}.{name}.{key} if available.
Otherwise falls back to {parent}.{key} (parent table defaults).
The parent is the parent table name (e.g., “measurement”).
The name is the specific identifier within that parent.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".