create_consolidated_pending_read_branch

Function create_consolidated_pending_read_branch 

pub fn create_consolidated_pending_read_branch() -> Result<ReadBranchGuard>
Creates a temporary read branch that consolidates ONLY pending writes (excludes remote). This is used by status and reset commands to see only local pending measurements. The returned guard must be kept alive for as long as the reference is needed. The temporary reference is automatically cleaned up when the guard is dropped.