get_commits_with_notes

Function get_commits_with_notes 

pub fn get_commits_with_notes(notes_ref: &str) -> Result<Vec<String>>
Get commits that have notes in a specific notes ref. This is much more efficient than walking all commits when you only need commits with measurements.

Returns a vector of commit SHAs that have notes in the specified ref.