get_notes_for_commit

Function get_notes_for_commit 

pub fn get_notes_for_commit(
    notes_ref: &str,
    commit_sha: &str,
) -> Result<Vec<String>>
Get the notes content for a specific commit from a notes ref. Returns the note lines as a vector of strings.