Module config

Functions

backoff_max_elapsed_seconds
Returns the backoff max elapsed seconds from config, or 60 if not set.
backoff_max_elapsed_seconds_from_str
Returns the backoff max elapsed seconds from a config string, or 60 if not set.
bump_epoch
bump_epoch_in_conf
determine_epoch_from_config
read_config
write_config