Creates a temporary read branch that consolidates ONLY pending writes (excludes remote).
This is used by status and reset commands to see only local pending measurements.
The returned guard must be kept alive for as long as the reference is needed.
The temporary reference is automatically cleaned up when the guard is dropped.
Creates a temporary read branch that consolidates all pending writes.
The returned guard must be kept alive for as long as the reference is needed.
The temporary reference is automatically cleaned up when the guard is dropped.
Creates a new write ref and updates the symbolic ref to point to it (public wrapper).
This is used to ensure concurrent writes go to a new location, preventing
race conditions during operations like reset or push.
Get detailed commit information (SHA, title, author) for specific commits.
This is more efficient than walking commits when you already know which commits you need.
Get commits that have notes in a specific notes ref.
This is much more efficient than walking all commits when you only need
commits with measurements.