pub fn create_new_write_ref() -> Result<String>Expand description
Creates a new write ref and updates the symbolic ref to point to it (public wrapper). This is used to ensure concurrent writes go to a new location, preventing race conditions during operations like reset or push.